pub enum Error {
Transport(String),
Serde(Error),
Auth(String),
RateLimit {
scope: &'static str,
weight: u32,
retry_after_ms: Option<u64>,
},
BadRequest(String),
Exchange(String),
Timeout,
Decode(String),
Http {
status: u16,
message: String,
},
UrlParse(ParseError),
Io(Error),
}Expand description
Error type for Polymarket HTTP operations.
Variants
Transport(String)
Serde(Error)
Auth(String)
RateLimit
BadRequest(String)
Exchange(String)
Timeout
Decode(String)
Http
UrlParse(ParseError)
Io(Error)
Implementations
Sourceimpl Error
impl Error
pub fn transport(msg: impl Into<String>) -> Self
pub fn auth(msg: impl Into<String>) -> Self
pub fn rate_limit( scope: &'static str, weight: u32, retry_after_ms: Option<u64>, ) -> Self
pub fn bad_request(msg: impl Into<String>) -> Self
pub fn exchange(msg: impl Into<String>) -> Self
pub fn decode(msg: impl Into<String>) -> Self
pub fn http(status: u16, message: impl Into<String>) -> Self
Sourcepub fn from_http_status(status: StatusCode, body: &[u8]) -> Self
pub fn from_http_status(status: StatusCode, body: &[u8]) -> Self
Classifies an HTTP status code and body into the appropriate error variant.
Sourcepub fn from_status_code(status: u16, body: &[u8]) -> Self
pub fn from_status_code(status: u16, body: &[u8]) -> Self
Classifies a raw status code (as u16) and body into the appropriate error variant.
Sourcepub fn from_reqwest(error: ReqwestError) -> Self
pub fn from_reqwest(error: ReqwestError) -> Self
Classifies a reqwest error into the appropriate error variant.
pub fn from_http_client(error: HttpClientError) -> Self
pub fn is_retryable(&self) -> bool
pub fn is_rate_limited(&self) -> bool
pub fn is_auth_error(&self) -> bool
Sourcepub fn is_http_status_error(&self) -> bool
pub fn is_http_status_error(&self) -> bool
Returns true if this error originated from an HTTP status code response
(as opposed to transport, timeout, or local errors).